Module: Upgrow::Record

Defined in:
lib/upgrow/record.rb

Overview

Utility mixin to help adjust Active Record Base classes according to Upgrow's conventions. It allows the use of the Record suffix in class naming while keeping it out of table and association names, among other adaptations.

Defined Under Namespace

Modules: ClassMethods

Class Method Summary collapse

Class Method Details

.included(base) ⇒ Object



117
118
119
# File 'lib/upgrow/record.rb', line 117

def self.included(base)
  base.extend(ClassMethods)
end